==> StatDA_1.0.tar.gz: StatDA/man/chorizon.Rd <==
\encoding{latin1}
\name{chorizon}
\alias{chorizon}
\docType{data}
\title{C-horizon of the Kola Data}
\description{
The Kola Data were collected in the Kola Project (1993-1998,
Geological Surveys of Finland (GTK) and Norway (NGU) and Central
Kola Expedition (CKE), Russia). More than 600 samples in five
different layers were analysed, this dataset contains the C-horizon.
}
\usage{data(chorizon)}
\format{
  A data frame with 606 observations on the following 111 variables.
  \describe{
    \item{\code{ID}}{a numeric vector}
    \item{\code{XCOO}}{a numeric vector}
    \item{\code{YCOO}}{a numeric vector}
    \item{\code{ELEV}}{a numeric vector}
    \item{\code{COUN}}{a factor with levels \code{FIN} \code{NOR} \code{RUS}}
    \item{\code{ASP}}{a factor with levels \code{} \code{E} \code{FLAT} \code{N} \code{NE} \code{NW} \code{ NW} \code{S} \code{SE} \code{SW} \code{W}}
    \item{\code{TOPC}}{a numeric vector}
    \item{\code{LITO}}{a numeric vector}
    \item{\code{Ag}}{a numeric vector}
    \item{\code{Ag_INAA}}{a numeric vector}
    \item{\code{Al}}{a numeric vector}
    \item{\code{Al_XRF}}{a numeric vector}
    \item{\code{Al2O3}}{a numeric vector}
    \item{\code{As}}{a numeric vector}
    \item{\code{As_INAA}}{a numeric vector}
    \item{\code{Au}}{a numeric vector}
    \item{\code{Au_INAA}}{a numeric vector}
    \item{\code{B}}{a numeric vector}
    \item{\code{Ba}}{a numeric vector}
    \item{\code{Ba_INAA}}{a numeric vector}
    \item{\code{Be}}{a numeric vector}
    \item{\code{Bi}}{a numeric vector}
    \item{\code{Br_IC}}{a numeric vector}
    \item{\code{Br_INAA}}{a numeric vector}
    \item{\code{Ca}}{a numeric vector}
    \item{\code{Ca_INAA}}{a numeric vector}
    \item{\code{Ca_XRF}}{a numeric vector}
    \item{\code{CaO}}{a numeric vector}
    \item{\code{Cd}}{a numeric vector}
    \item{\code{Ce_INAA}}{a numeric vector}
    \item{\code{Cl_IC}}{a numeric vector}
    \item{\code{Co}}{a numeric vector}
    \item{\code{Co_INAA}}{a numeric vector}
    \item{\code{Cr}}{a numeric vector}
    \item{\code{Cr_INAA}}{a numeric vector}
    \item{\code{Cs_INAA}}{a numeric vector}
    \item{\code{Cu}}{a numeric vector}
    \item{\code{EC}}{a numeric vector}
    \item{\code{Eu_INAA}}{a numeric vector}
    \item{\code{F_IC}}{a numeric vector}
    \item{\code{Fe}}{a numeric vector}
    \item{\code{Fe_INAA}}{a numeric vector}
    \item{\code{Fe_XRF}}{a numeric vector}
    \item{\code{Fe2O3}}{a numeric vector}
    \item{\code{Hf_INAA}}{a numeric vector}
    \item{\code{Hg}}{a numeric vector}
    \item{\code{Hg_INAA}}{a numeric vector}
    \item{\code{Ir_INAA}}{a numeric vector}
    \item{\code{K}}{a numeric vector}
    \item{\code{K_XRF}}{a numeric vector}
    \item{\code{K2O}}{a numeric vector}
    \item{\code{La}}{a numeric vector}
    \item{\code{La_INAA}}{a numeric vector}
    \item{\code{Li}}{a numeric vector}
    \item{\code{LOI}}{a numeric vector}
    \item{\code{Lu_INAA}}{a numeric vector}
    \item{\code{Mg}}{a numeric vector}
    \item{\code{Mg_XRF}}{a numeric vector}
    \item{\code{MgO}}{a numeric vector}
    \item{\code{Mn}}{a numeric vector}
    \item{\code{Mn_XRF}}{a numeric vector}
    \item{\code{MnO}}{a numeric vector}
    \item{\code{Mo}}{a numeric vector}
    \item{\code{Mo_INAA}}{a numeric vector}
    \item{\code{Na}}{a numeric vector}
    \item{\code{Na_INAA}}{a numeric vector}
    \item{\code{Na_XRF}}{a numeric vector}
    \item{\code{Na2O}}{a numeric vector}
    \item{\code{Nd_INAA}}{a numeric vector}
    \item{\code{Ni}}{a numeric vector}
    \item{\code{Ni_INAA}}{a numeric vector}
    \item{\code{NO3_IC}}{a numeric vector}
    \item{\code{P}}{a numeric vector}
    \item{\code{P_XRF}}{a numeric vector}
    \item{\code{P2O5}}{a numeric vector}
    \item{\code{Pb}}{a numeric vector}
    \item{\code{Pd}}{a numeric vector}
    \item{\code{pH}}{a numeric vector}
    \item{\code{PO4_IC}}{a numeric vector}
    \item{\code{Pt}}{a numeric vector}
    \item{\code{Rb}}{a numeric vector}
    \item{\code{S}}{a numeric vector}
    \item{\code{Sb}}{a numeric vector}
    \item{\code{Sb_INAA}}{a numeric vector}
    \item{\code{Sc}}{a numeric vector}
    \item{\code{Sc_INAA}}{a numeric vector}
    \item{\code{Se}}{a numeric vector}
    \item{\code{Se_INAA}}{a numeric vector}
    \item{\code{Si}}{a numeric vector}
    \item{\code{Si_XRF}}{a numeric vector}
    \item{\code{SiO2}}{a numeric vector}
    \item{\code{Sm_INAA}}{a numeric vector}
    \item{\code{Sn_INAA}}{a numeric vector}
    \item{\code{SO4_IC}}{a numeric vector}
    \item{\code{Sr}}{a numeric vector}
    \item{\code{Sr_INAA}}{a numeric vector}
    \item{\code{Ta_INAA}}{a numeric vector}
    \item{\code{Tb_INAA}}{a numeric vector}
    \item{\code{Te}}{a numeric vector}
    \item{\code{Th}}{a numeric vector}
    \item{\code{Th_INAA}}{a numeric vector}
    \item{\code{Ti}}{a numeric vector}
    \item{\code{Ti_XRF}}{a numeric vector}
    \item{\code{TiO2}}{a numeric vector}
    \item{\code{U_INAA}}{a numeric vector}
    \item{\code{V}}{a numeric vector}
    \item{\code{W_INAA}}{a numeric vector}
    \item{\code{Y}}{a numeric vector}
    \item{\code{Yb_INAA}}{a numeric vector}
    \item{\code{Zn}}{a numeric vector}
    \item{\code{Zn_INAA}}{a numeric vector}
  }
}
\source{
Kola Project (1993-1998)
}
\references{
Reimann C, yrs M, Chekushin V, Bogatyrev I, Boyd R, Caritat P de, Dutter R,
Finne TE, Halleraker JH, Jger , Kashulina G, Lehto O, Niskavaara H, Pavlov V,
Risnen ML, Strand T, Volden T. Environmental Geochemical Atlas of the Central
Barents Region. NGU-GTK-CKE Special Publication, Geological Survey of Norway,
Trondheim, Norway, 1998.
}
\examples{
data(chorizon)
str(chorizon)
}
\keyword{datasets}

==> StatDA_1.6.3.tar.gz: StatDA/man/chorizon.Rd <==
\encoding{latin1}
\name{chorizon}
\alias{chorizon}
\docType{data}
\title{C-horizon of the Kola Data}
\description{
The Kola Data were collected in the Kola Project (1993-1998,
Geological Surveys of Finland (GTK) and Norway (NGU) and Central
Kola Expedition (CKE), Russia). More than 600 samples in five
different layers were analysed, this dataset contains the C-horizon.
}
\usage{data(chorizon)}
\format{
  A data frame with 606 observations on the following 111 variables.
  \describe{
    \item{\code{ID}}{a numeric vector}
    \item{\code{XCOO}}{a numeric vector}
    \item{\code{YCOO}}{a numeric vector}
    \item{\code{ELEV}}{a numeric vector}
    \item{\code{COUN}}{a factor with levels \code{FIN} \code{NOR} \code{RUS}}
    \item{\code{ASP}}{a factor with levels \code{} \code{E} \code{FLAT} \code{N} \code{NE} \code{NW} \code{ NW} \code{S} \code{SE} \code{SW} \code{W}}
    \item{\code{TOPC}}{a numeric vector}
    \item{\code{LITO}}{a numeric vector}
    \item{\code{Ag}}{a numeric vector}
    \item{\code{Ag_INAA}}{a numeric vector}
    \item{\code{Al}}{a numeric vector}
    \item{\code{Al_XRF}}{a numeric vector}
    \item{\code{Al2O3}}{a numeric vector}
    \item{\code{As}}{a numeric vector}
    \item{\code{As_INAA}}{a numeric vector}
    \item{\code{Au}}{a numeric vector}
    \item{\code{Au_INAA}}{a numeric vector}
    \item{\code{B}}{a numeric vector}
    \item{\code{Ba}}{a numeric vector}
    \item{\code{Ba_INAA}}{a numeric vector}
    \item{\code{Be}}{a numeric vector}
    \item{\code{Bi}}{a numeric vector}
    \item{\code{Br_IC}}{a numeric vector}
    \item{\code{Br_INAA}}{a numeric vector}
    \item{\code{Ca}}{a numeric vector}
    \item{\code{Ca_INAA}}{a numeric vector}
    \item{\code{Ca_XRF}}{a numeric vector}
    \item{\code{CaO}}{a numeric vector}
    \item{\code{Cd}}{a numeric vector}
    \item{\code{Ce_INAA}}{a numeric vector}
    \item{\code{Cl_IC}}{a numeric vector}
    \item{\code{Co}}{a numeric vector}
    \item{\code{Co_INAA}}{a numeric vector}
    \item{\code{Cr}}{a numeric vector}
    \item{\code{Cr_INAA}}{a numeric vector}
    \item{\code{Cs_INAA}}{a numeric vector}
    \item{\code{Cu}}{a numeric vector}
    \item{\code{EC}}{a numeric vector}
    \item{\code{Eu_INAA}}{a numeric vector}
    \item{\code{F_IC}}{a numeric vector}
    \item{\code{Fe}}{a numeric vector}
    \item{\code{Fe_INAA}}{a numeric vector}
    \item{\code{Fe_XRF}}{a numeric vector}
    \item{\code{Fe2O3}}{a numeric vector}
    \item{\code{Hf_INAA}}{a numeric vector}
    \item{\code{Hg}}{a numeric vector}
    \item{\code{Hg_INAA}}{a numeric vector}
    \item{\code{Ir_INAA}}{a numeric vector}
    \item{\code{K}}{a numeric vector}
    \item{\code{K_XRF}}{a numeric vector}
    \item{\code{K2O}}{a numeric vector}
    \item{\code{La}}{a numeric vector}
    \item{\code{La_INAA}}{a numeric vector}
    \item{\code{Li}}{a numeric vector}
    \item{\code{LOI}}{a numeric vector}
    \item{\code{Lu_INAA}}{a numeric vector}
    \item{\code{Mg}}{a numeric vector}
    \item{\code{Mg_XRF}}{a numeric vector}
    \item{\code{MgO}}{a numeric vector}
    \item{\code{Mn}}{a numeric vector}
    \item{\code{Mn_XRF}}{a numeric vector}
    \item{\code{MnO}}{a numeric vector}
    \item{\code{Mo}}{a numeric vector}
    \item{\code{Mo_INAA}}{a numeric vector}
    \item{\code{Na}}{a numeric vector}
    \item{\code{Na_INAA}}{a numeric vector}
    \item{\code{Na_XRF}}{a numeric vector}
    \item{\code{Na2O}}{a numeric vector}
    \item{\code{Nd_INAA}}{a numeric vector}
    \item{\code{Ni}}{a numeric vector}
    \item{\code{Ni_INAA}}{a numeric vector}
    \item{\code{NO3_IC}}{a numeric vector}
    \item{\code{P}}{a numeric vector}
    \item{\code{P_XRF}}{a numeric vector}
    \item{\code{P2O5}}{a numeric vector}
    \item{\code{Pb}}{a numeric vector}
    \item{\code{Pd}}{a numeric vector}
    \item{\code{pH}}{a numeric vector}
    \item{\code{PO4_IC}}{a numeric vector}
    \item{\code{Pt}}{a numeric vector}
    \item{\code{Rb}}{a numeric vector}
    \item{\code{S}}{a numeric vector}
    \item{\code{Sb}}{a numeric vector}
    \item{\code{Sb_INAA}}{a numeric vector}
    \item{\code{Sc}}{a numeric vector}
    \item{\code{Sc_INAA}}{a numeric vector}
    \item{\code{Se}}{a numeric vector}
    \item{\code{Se_INAA}}{a numeric vector}
    \item{\code{Si}}{a numeric vector}
    \item{\code{Si_XRF}}{a numeric vector}
    \item{\code{SiO2}}{a numeric vector}
    \item{\code{Sm_INAA}}{a numeric vector}
    \item{\code{Sn_INAA}}{a numeric vector}
    \item{\code{SO4_IC}}{a numeric vector}
    \item{\code{Sr}}{a numeric vector}
    \item{\code{Sr_INAA}}{a numeric vector}
    \item{\code{Ta_INAA}}{a numeric vector}
    \item{\code{Tb_INAA}}{a numeric vector}
    \item{\code{Te}}{a numeric vector}
    \item{\code{Th}}{a numeric vector}
    \item{\code{Th_INAA}}{a numeric vector}
    \item{\code{Ti}}{a numeric vector}
    \item{\code{Ti_XRF}}{a numeric vector}
    \item{\code{TiO2}}{a numeric vector}
    \item{\code{U_INAA}}{a numeric vector}
    \item{\code{V}}{a numeric vector}
    \item{\code{W_INAA}}{a numeric vector}
    \item{\code{Y}}{a numeric vector}
    \item{\code{Yb_INAA}}{a numeric vector}
    \item{\code{Zn}}{a numeric vector}
    \item{\code{Zn_INAA}}{a numeric vector}
  }
}
\source{
Kola Project (1993-1998)
}
\references{
Reimann C, yrs M, Chekushin V, Bogatyrev I, Boyd R, Caritat P de, Dutter R,
Finne TE, Halleraker JH, Jger , Kashulina G, Lehto O, Niskavaara H, Pavlov V,
Risnen ML, Strand T, Volden T. Environmental Geochemical Atlas of the Central
Barents Region. NGU-GTK-CKE Special Publication, Geological Survey of Norway,
Trondheim, Norway, 1998.
}
\author{ Peter Filzmoser <\email{P.Filzmoser@tuwien.ac.at}>
\url{http://www.statistik.tuwien.ac.at/public/filz/}}
\examples{
data(chorizon)
str(chorizon)
}
\keyword{datasets}
